@@ -14,20 +14,12 @@ async fn main() -> Result<(), Box<dyn Error>> {
     //Connect with a set timeout
     camera.connect(Duration::from_secs(10)).await.unwrap();
 
-    dbg!("connected");
-
-    time::sleep(Duration::from_secs(5)).await;
-
-    time::sleep(Duration::from_secs(5)).await;
-
     //Change the ISO to 320
     camera
         .write(255, Operation::AssignValue, Command::Video(Video::Iso(320)))
         .await
         .unwrap();
 
-    dbg!("i am past");
-
     //Subscribe to updates from the camera;
     let mut updates = camera.updates().await;
 
@@ -45,6 +37,14 @@ async fn main() -> Result<(), Box<dyn Error>> {
 
     time::sleep(Duration::from_secs(5)).await;
 
+    //Change the ISO to 640
+    camera
+        .write(255, Operation::AssignValue, Command::Video(Video::Iso(640)))
+        .await
+        .unwrap();
+
+    time::sleep(Duration::from_secs(1)).await;
+
     // Get a specific piece of info from the cached properties
     let info = camera
         .get(Command::Metadata(Metadata::LensDistance("".to_string())))
